@@ -1,7 +1,7 @@
 package Color::RGB::Util;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.58'; # VERSION
+our $DATE = '2018-09-26'; # DATE
+our $VERSION = '0.590'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,23 +19,23 @@ our @EXPORT_OK = qw(
                        rgb2sepia
                        rgb_luminance
                        tint_rgb_color
+                       rgb_distance
+                       rgb_is_dark
+                       rgb_is_light
                );
 
+my $re_rgb = qr/\A#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})\z/;
+
 sub mix_2_rgb_colors {
     my ($rgb1, $rgb2, $pct) = @_;
 
     $pct //= 0.5;
 
-    $rgb1 =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid rgb1 color, must be in 'ffffff' form";
-    my $r1 = hex($1);
-    my $g1 = hex($2);
-    my $b1 = hex($3);
-    $rgb2 =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid rgb2 color, must be in 'ffffff' form";
-    my $r2 = hex($1);
-    my $g2 = hex($2);
-    my $b2 = hex($3);
+    my ($r1, $g1, $b1) =
+        $rgb1 =~ $re_rgb or die "Invalid rgb1 color, must be in 'ffffff' form";
+    my ($r2, $g2, $b2) =
+        $rgb2 =~ $re_rgb or die "Invalid rgb2 color, must be in 'ffffff' form";
+    for ($r1, $g1, $b1, $r2, $g2, $b2) { $_ = hex $_ }
 
     return sprintf("%02x%02x%02x",
                    $r1 + $pct*($r2-$r1),
@@ -48,17 +48,12 @@ sub rand_rgb_color {
     my ($rgb1, $rgb2) = @_;
 
     $rgb1 //= '000000';
-    $rgb1 =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid rgb1 color, must be in 'ffffff' form";
-    my $r1 = hex($1);
-    my $g1 = hex($2);
-    my $b1 = hex($3);
+    my ($r1, $g1, $b1) =
+        $rgb1 =~ $re_rgb or die "Invalid rgb1 color, must be in 'ffffff' form";
     $rgb2 //= 'ffffff';
-    $rgb2 =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid rgb2 color, must be in 'ffffff' form";
-    my $r2 = hex($1);
-    my $g2 = hex($2);
-    my $b2 = hex($3);
+    my ($r2, $g2, $b2) =
+        $rgb2 =~ $re_rgb or die "Invalid rgb2 color, must be in 'ffffff' form";
+    for ($r1, $g1, $b1, $r2, $g2, $b2) { $_ = hex $_ }
 
     return sprintf("%02x%02x%02x",
                    $r1 + rand()*($r2-$r1+1),
@@ -70,11 +65,9 @@ sub rand_rgb_color {
 sub rgb2grayscale {
     my ($rgb) = @_;
 
-    $rgb =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid rgb color, must be in 'ffffff' form";
-    my $r = hex($1);
-    my $g = hex($2);
-    my $b = hex($3);
+    my ($r, $g, $b) =
+        $rgb =~ $re_rgb or die "Invalid rgb color, must be in 'ffffff' form";
+    for ($r, $g, $b) { $_ = hex $_ }
 
     # basically we just average the R, G, B
     my $avg = int(($r + $g + $b)/3);
@@ -84,11 +77,9 @@ sub rgb2grayscale {
 sub rgb2sepia {
     my ($rgb) = @_;
 
-    $rgb =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid rgb color, must be in 'ffffff' form";
-    my $r = hex($1);
-    my $g = hex($2);
-    my $b = hex($3);
+    my ($r, $g, $b) =
+        $rgb =~ $re_rgb or die "Invalid rgb color, must be in 'ffffff' form";
+    for ($r, $g, $b) { $_ = hex $_ }
 
     # reference: http://www.techrepublic.com/blog/howdoi/how-do-i-convert-images-to-grayscale-and-sepia-tone-using-c/120
     my $or = ($r*0.393) + ($g*0.769) + ($b*0.189);
@@ -101,11 +92,9 @@ sub rgb2sepia {
 sub reverse_rgb_color {
     my ($rgb) = @_;
 
-    $rgb =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid rgb color, must be in 'ffffff' form";
-    my $r = hex($1);
-    my $g = hex($2);
-    my $b = hex($3);
+    my ($r, $g, $b) =
+        $rgb =~ $re_rgb or die "Invalid rgb color, must be in 'ffffff' form";
+    for ($r, $g, $b) { $_ = hex $_ }
 
     return sprintf("%02x%02x%02x", 255-$r, 255-$g, 255-$b);
 }
@@ -118,11 +107,9 @@ sub _rgb_luminance {
 sub rgb_luminance {
     my ($rgb) = @_;
 
-    $rgb =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid rgb color, must be in 'ffffff' form";
-    my $r = hex($1);
-    my $g = hex($2);
-    my $b = hex($3);
+    my ($r, $g, $b) =
+        $rgb =~ $re_rgb or die "Invalid rgb color, must be in 'ffffff' form";
+    for ($r, $g, $b) { $_ = hex $_ }
 
     return _rgb_luminance($r, $g, $b);
 }
@@ -132,16 +119,11 @@ sub tint_rgb_color {
 
     $pct //= 0.5;
 
-    $rgb1 =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid rgb color, must be in 'ffffff' form";
-    my $r1 = hex($1);
-    my $g1 = hex($2);
-    my $b1 = hex($3);
-    $rgb2 =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
-        or die "Invalid tint color, must be in 'ffffff' form";
-    my $r2 = hex($1);
-    my $g2 = hex($2);
-    my $b2 = hex($3);
+    my ($r1, $g1, $b1) =
+        $rgb1 =~ $re_rgb or die "Invalid rgb1 color, must be in 'ffffff' form";
+    my ($r2, $g2, $b2) =
+        $rgb2 =~ $re_rgb or die "Invalid rgb2 color, must be in 'ffffff' form";
+    for ($r1, $g1, $b1, $r2, $g2, $b2) { $_ = hex $_ }
 
     my $lum = _rgb_luminance($r1, $g1, $b1);
 
@@ -152,6 +134,28 @@ sub tint_rgb_color {
                );
 }
 
+sub rgb_distance {
+    my ($rgb1, $rgb2) = @_;
+
+    my ($r1, $g1, $b1) =
+        $rgb1 =~ $re_rgb or die "Invalid rgb1 color, must be in 'ffffff' form";
+    my ($r2, $g2, $b2) =
+        $rgb2 =~ $re_rgb or die "Invalid rgb2 color, must be in 'ffffff' form";
+    for ($r1, $g1, $b1, $r2, $g2, $b2) { $_ = hex $_ }
+
+    (($r1-$r2)**2 + ($g1-$g2)**2 + ($b1-$b2)**2)**0.5;
+}
+
+sub rgb_is_dark {
+    my ($rgb) = @_;
+    rgb_distance($rgb, "000000") < rgb_distance($rgb, "ffffff") ? 1:0;
+}
+
+sub rgb_is_light {
+    my ($rgb) = @_;
+    rgb_distance($rgb, "000000") > rgb_distance($rgb, "ffffff") ? 1:0;
+}
+
 1;
 # ABSTRACT: Utilities related to RGB colors
 
@@ -167,7 +171,7 @@ Color::RGB::Util - Utilities related to RGB colors
 
 =head1 VERSION
 
-This document describes version 0.58 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2015-01-03.
+This document describes version 0.590 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2018-09-26.
 
 =head1 SYNOPSIS
 
@@ -200,29 +204,53 @@ This document describes version 0.58 of Color::RGB::Util (from Perl distribution
 
 None are exported by default, but they are exportable.
 
-=head2 mix_2_rgb_colors($rgb1, $rgb2, $pct) => STR
+=head2 mix_2_rgb_colors
+
+Usage:
+
+ my $mixed_rgb = mix_2_rgb_colors($rgb1, $rgb2, $pct);
 
 Mix 2 RGB colors. C<$pct> is a number between 0 and 1, by default 0.5 (halfway),
 the closer to 1 the closer the resulting color to C<$rgb2>.
 
-=head2 rand_rgb_color([$low_limit[, $high_limit]]) => STR
+=head2 rand_rgb_color
+
+Usage:
+
+ my $rgb = rand_rgb_color([ $low_limit [ , $high_limit ] ]);
 
 Generate a random RGB color. You can specify the limit. Otherwise, they default
 to the full range (000000 to ffffff).
 
-=head2 rgb2grayscale($rgb) => RGB
+=head2 rgb2grayscale
+
+Usage:
+
+ my $rgb_gs = rgb2grayscale($rgb);
 
 Convert C<$rgb> to grayscale RGB value.
 
-=head2 rgb2sepia($rgb) => RGB
+=head2 rgb2sepia
+
+Usage:
+
+ my $rgb_sepia = rgb2sepia($rgb);
 
 Convert C<$rgb> to sepia tone RGB value.
 
-=head2 reverse_rgb_color($rgb) => RGB
+=head2 reverse_rgb_color
+
+Usage:
+
+ my $reversed = reverse_rgb_color($rgb);
 
 Reverse C<$rgb>.
 
-=head2 rgb_luminance($rgb) => NUM
+=head2 rgb_luminance
+
+Usage:
+
+ my $luminance = rgb_luminance($rgb);
 
 Calculate standard/objective luminance from RGB value using this formula:
 
@@ -230,15 +258,46 @@ Calculate standard/objective luminance from RGB value using this formula:
 
 where R, G, and B range from 0 to 1. Return a number from 0 to 1.
 
-=head2 tint_rgb_color($rgb, $tint_rgb, $pct) => RGB
+=head2 tint_rgb_color
+
+Usage:
+
+ my $new_rgb = tint_rgb_color($rgb, $tint_rgb, $pct)
 
 Tint C<$rgb> with C<$tint_rgb>. $pct is by default 0.5. It is similar to mixing,
 but the less luminance the color is the less it is tinted with the tint color.
 This has the effect of black color still being black instead of becoming tinted.
 
-=head1 SEE ALSO
+=head2 rgb_distance
 
-L<Color::ANSI::Util>
+Usage:
+
+ my $dist = rgb_distance($rgb1, $rgb2)
+
+Calculate RGB distance, which is defined as:
+
+ ((R1-R2)**2 + (G1-G2)**2 + (B1-B2)**2)**0.5
+
+For example, the distance between "000000" and "ffffff" is ~441.67, while the
+distance between "ffff00" and "ffffff" is 255.
+
+=head2 rgb_is_dark
+
+Usage:
+
+ my $is_dark = rgb_is_dark($rgb)
+
+Return true if C<$rgb> is a "dark" color, which is determined by checking if the
+RGB distance to "000000" is smaller than to "ffffff".
+
+=head2 rgb_is_light
+
+Usage:
+
+ my $is_light = rgb_is_light($rgb)
+
+Return true if C<$rgb> is a "light" color, which is determined by checking if
+the RGB distance to "000000" is larger than to "ffffff".
 
 =head1 HOMEPAGE
 
@@ -256,13 +315,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Color::ANSI::Util>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
